import { formatHashTag, formatImgUrl } from "@/common/fotmat";
import Counter from "@/components/counter";
import MCheckbox from "@/components/checkbox";
import { Image, Text, View } from "@tarojs/components";
import { FC, memo, useCallback } from "react";
import styles  from './index.module.scss'

type OrderParam = {
    list?: any[], 
    sale_mode?: number,
    sale_mode_name?: string,
    unit?: string,
    total_colors?: number,
    total_fabrics?: number,
    total_number?: number,
    status?: number, //订单状态
}

type Param = {
    order: OrderParam,
    onNumChange?: (val:any) => void
}

const kindeList:FC<Param> =  memo(({order, onNumChange}) => {
    //对应数量
    const formatCount = useCallback((item) => {
        return (item.roll - item.return_roll - item.apply_return_roll) + order?.unit!
    }, [order])

    //计步器失返回值
    const getCounterChange = useCallback((colorItem) => {
        return (number) => {
            onNumChange?.({number, color_id: colorItem.id, sale_order_detail_id:colorItem.sale_order_detail_id})
        }
    }, [])

    //判断该面料下的颜色都退完了
    const colorNum = (item) => {
        let res = item.product_colors.some(val => {
            return (val.return_roll + val.apply_return_roll) < val.roll
        })
        return res
    }

    return (
        <View className={styles.apply_after_sales_list}>
            {order?.list?.map(item => (colorNum(item))&&<View className={styles.apply_after_sales_item}>
                <View className={styles.apply_after_sales_title}>
                    <View className={styles.tag}>{order.sale_mode_name}</View>
                    <View className={styles.title}>{formatHashTag(item.code, item.name)}</View>
                </View>
                <View className={styles.color_list}>
                    {item.product_colors.map(colorItem => ((colorItem.return_roll + colorItem.apply_return_roll) < colorItem.roll)&&<View className={styles.color_item}>
                        <View className={styles.image}><Image src={formatImgUrl('')}/></View>
                        <View className={styles.name_and_number}><Text>{colorItem.code + ' ' + colorItem.name}</Text><Text>x {formatCount(colorItem)}</Text></View>
                        <View className={styles.btn_count}>
                            <Counter maxNum={colorItem.roll - (colorItem.return_roll + colorItem.apply_return_roll)} onChange={getCounterChange(colorItem)}/>
                        </View>
                    </View>)}
                </View>
            </View>)}
        </View>
    )
})

export default kindeList